==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1DeploymentStrategyFluent.java <==
package io.kubernetes.client.models;

import java.lang.Deprecated;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Boolean;

public interface V1DeploymentStrategyFluent<A extends V1DeploymentStrategyFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildRollingUpdate instead.
 * @return The buildable object.
 */
@Deprecated public V1RollingUpdateDeployment getRollingUpdate();
    public V1RollingUpdateDeployment buildRollingUpdate();
    public A withRollingUpdate(V1RollingUpdateDeployment rollingUpdate);
    public Boolean hasRollingUpdate();
    public V1DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate();
    public V1DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(V1RollingUpdateDeployment item);
    public V1DeploymentStrategyFluent.RollingUpdateNested<A> editRollingUpdate();
    public V1DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate();
    public V1DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(V1RollingUpdateDeployment item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();

    public interface RollingUpdateNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1RollingUpdateDeploymentFluent<V1DeploymentStrategyFluent.RollingUpdateNested<N>>{

        
    public N and();    public N endRollingUpdate();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1DeploymentStrategyFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1DeploymentStrategyFluent<A extends V1DeploymentStrategyFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildRollingUpdate instead.
 * @return The buildable object.
 */
@Deprecated public V1RollingUpdateDeployment getRollingUpdate();
    public V1RollingUpdateDeployment buildRollingUpdate();
    public A withRollingUpdate(V1RollingUpdateDeployment rollingUpdate);
    public Boolean hasRollingUpdate();
    public V1DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate();
    public V1DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(V1RollingUpdateDeployment item);
    public V1DeploymentStrategyFluent.RollingUpdateNested<A> editRollingUpdate();
    public V1DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate();
    public V1DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(V1RollingUpdateDeployment item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);

    public interface RollingUpdateNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1RollingUpdateDeploymentFluent<V1DeploymentStrategyFluent.RollingUpdateNested<N>>{

        
    public N and();    public N endRollingUpdate();
}


}
